@@ -1,6 +1,9 @@
+import sys
 import convertible
 import inspect
 import logger
+import logging
+import traceback
 
 log = logger.get_logger('app')
 
@@ -32,8 +35,11 @@ def run(runner, debug=False, text=False, exit_code_on_error=1):
         else:
             respond(data)
     except Exception, e:
-        log.exception('got an exception')
-        respond(e, str(e), success=False)
+        all_info_lines = traceback.format_exception(sys.exc_type, sys.exc_value, sys.exc_traceback)
+        all_info_text = ''.join(all_info_lines)
+        exc_info_lines = traceback.format_exception_only(sys.exc_type, sys.exc_value)
+        exc_info_text = ''.join(exc_info_lines)
+        respond(all_info_text, exc_info_text, success=False)
         exit(exit_code_on_error)
 
 
@@ -42,4 +48,10 @@ def execute(obj, args, exit_code_on_error=1):
     text = False
     if hasattr(args, 'text'):
         text = args.text
-    run(lambda: call(method, vars(args)), args.debug, text, exit_code_on_error)
\ No newline at end of file
+    run(lambda: call(method, vars(args)), args.debug, text, exit_code_on_error)
+
+def init_log(name, args):
+    if args.debug:
+        logger.console = True
+        logger.level = logging.DEBUG
+    logger.init('/tmp/{}.log'.format(name))
